django-simple-history
=====================

django-simple-history stores Django model state on every create/update/delete.

Documentation
-------------

.. toctree::
   :maxdepth: 2

   usage
   advanced

Code
----

Code and issue tracker: https://github.com/treyhunner/django-simple-history

Pull requests are welcome.


.. include:: ../CHANGES.rst
